@@ -1,5 +1,12 @@
 from dataclasses import (
-    asdict, astuple, dataclass, field, fields, make_dataclass, replace
+    MISSING,
+    asdict,
+    astuple,
+    dataclass,
+    field as _field,
+    fields,
+    make_dataclass,
+    replace,
 )
 import functools
 import xmod
@@ -16,7 +23,7 @@ __all__ = (
     'mutable',
     'replace',
 )
-__version__ = '4.0.0'
+__version__ = '4.1.0'
 
 _METHODS = 'asdict', 'astuple', 'fields', 'replace'
 _CLASS_METHODS = {'field_names', 'fields'}
@@ -42,6 +49,11 @@ def mutable(cls=None, **kwargs):
     return dcls
 
 
+@functools.wraps(_field)
+def field(default_factory=MISSING, **kwargs):
+    return _field(default_factory=default_factory, **kwargs)
+
+
 def add_methods(dcls):
     methods = (m for m in _METHODS if not hasattr(dcls, m))
     for m in methods:
